==> apache-dubbo-3.0.13-src.zip: apache-dubbo-3.0.13-src/dubbo-remoting/dubbo-remoting-api/src/test/java/org/apache/dubbo/remoting/utils/PayloadDropperTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.remoting.utils;

import org.apache.dubbo.remoting.exchange.Request;
import org.apache.dubbo.remoting.exchange.Response;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class PayloadDropperTest {
    @Test
    public void test() {
        Request request = new Request(1);
        request.setData(new Object());
        Request requestWithoutData = (Request) PayloadDropper.getRequestWithoutData(request);
        Assertions.assertEquals(requestWithoutData.getId(), request.getId());
        Assertions.assertNull(requestWithoutData.getData());

        Response response = new Response(1);
        response.setResult(new Object());
        Response responseWithoutData = (Response) PayloadDropper.getRequestWithoutData(response);
        Assertions.assertEquals(responseWithoutData.getId(), response.getId());
        Assertions.assertNull(responseWithoutData.getResult());

        Object object = new Object();
        Assertions.assertEquals(object, PayloadDropper.getRequestWithoutData(object));
    }
}

==> apache-dubbo-3.3.6-src.zip: apache-dubbo-3.3.6-src/dubbo-remoting/dubbo-remoting-api/src/test/java/org/apache/dubbo/remoting/utils/PayloadDropperTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.dubbo.remoting.utils;

import org.apache.dubbo.remoting.exchange.Request;
import org.apache.dubbo.remoting.exchange.Response;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

class PayloadDropperTest {
    @Test
    void test() {
        Request request = new Request(1);
        request.setData(new Object());
        Request requestWithoutData = (Request) PayloadDropper.getRequestWithoutData(request);
        Assertions.assertEquals(requestWithoutData.getId(), request.getId());
        Assertions.assertNull(requestWithoutData.getData());

        Response response = new Response(1);
        response.setResult(new Object());
        Response responseWithoutData = (Response) PayloadDropper.getRequestWithoutData(response);
        Assertions.assertEquals(responseWithoutData.getId(), response.getId());
        Assertions.assertNull(responseWithoutData.getResult());

        Object object = new Object();
        Assertions.assertEquals(object, PayloadDropper.getRequestWithoutData(object));
    }
}
